==> haskell-conduit-parse-0.2.1.1-188-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-conduit-parse.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 conduit-parse
version:              0.2.1.1
visibility:           public
id:                   conduit-parse-0.2.1.1-2yR9g9DPOJfPhY0OY7fZf
key:                  conduit-parse-0.2.1.1-2yR9g9DPOJfPhY0OY7fZf
license:              LicenseRef-PublicDomain
maintainer:           koral <koral@mailoo.org>
author:               koral <koral@mailoo.org>
homepage:             https://github.com/k0ral/conduit-parse
synopsis:             Parsing framework based on conduit.
description:          Please refer to README.
category:             Conduit, Text
abi:                  662f39975865a91a41f2bd275c6648b7
exposed:              True
exposed-modules:      Data.Conduit.Parser
hidden-modules:       Data.Conduit.Parser.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/conduit-parse-0.2.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/conduit-parse-0.2.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/conduit-parse-0.2.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-conduit-parse
hs-libraries:         HSconduit-parse-0.2.1.1-2yR9g9DPOJfPhY0OY7fZf
depends:
    base-4.17.2.1 conduit-1.3.6.1-L447JUvNddBC7PkE6UyQyv
    dlist-1.0-I6FB5Nlk17hG16fxQzZSEb mtl-2.2.2
    parsers-0.12.12-5LCISG6GPucCrvtSie0lHl
    safe-0.3.21-BBVCREVAhYi1ojPWc3Ddy2
    safe-exceptions-0.1.7.4-1nGG81acQaS86ZDpBRuA0H text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-conduit-parse/html/conduit-parse.haddock

haddock-html:         /usr/share/doc/haskell-conduit-parse/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-conduit-parse-0.2.1.1-189-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-conduit-parse.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 conduit-parse
version:              0.2.1.1
visibility:           public
id:                   conduit-parse-0.2.1.1-H7A1dtjFBvYDkNA4UiCDAH
key:                  conduit-parse-0.2.1.1-H7A1dtjFBvYDkNA4UiCDAH
license:              LicenseRef-PublicDomain
maintainer:           koral <koral@mailoo.org>
author:               koral <koral@mailoo.org>
homepage:             https://github.com/k0ral/conduit-parse
synopsis:             Parsing framework based on conduit.
description:          Please refer to README.
category:             Conduit, Text
abi:                  c1e9dc564485fc196366f039ac31f408
exposed:              True
exposed-modules:      Data.Conduit.Parser
hidden-modules:       Data.Conduit.Parser.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/conduit-parse-0.2.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/conduit-parse-0.2.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/conduit-parse-0.2.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-conduit-parse
hs-libraries:         HSconduit-parse-0.2.1.1-H7A1dtjFBvYDkNA4UiCDAH
depends:
    base-4.17.2.1 conduit-1.3.6.1-KbvjUYjGZ6BDMEb3OqHdCI
    dlist-1.0-I6FB5Nlk17hG16fxQzZSEb mtl-2.2.2
    parsers-0.12.12-CQK003mX4FkGQ5UqIRNCF8
    safe-0.3.21-4dOvXTUjyTXF7ZNQNu197N
    safe-exceptions-0.1.7.4-5w6XO7RpbmiEEPwXahsA3g text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-conduit-parse/html/conduit-parse.haddock

haddock-html:         /usr/share/doc/haskell-conduit-parse/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
